@@ -6,7 +6,6 @@ import (
 	"crypto/rand"
 	"crypto/rsa"
 	"encoding/pem"
-	"regexp"
 	"testing"
 	"time"
 
@@ -22,7 +21,7 @@ func TestGeneratePrivateKey(t *testing.T) {
 }
 
 func TestGenerateCSR(t *testing.T) {
-	privateKey, err := rsa.GenerateKey(rand.Reader, 512)
+	privateKey, err := rsa.GenerateKey(rand.Reader, 1024)
 	require.NoError(t, err, "Error generating private key")
 
 	type expected struct {
@@ -43,7 +42,7 @@ func TestGenerateCSR(t *testing.T) {
 				Domain:     "lego.acme",
 				MustStaple: true,
 			},
-			expected: expected{len: 245},
+			expected: expected{len: 379},
 		},
 		{
 			desc:       "without SAN (empty)",
@@ -53,7 +52,7 @@ func TestGenerateCSR(t *testing.T) {
 				SAN:        []string{},
 				MustStaple: true,
 			},
-			expected: expected{len: 245},
+			expected: expected{len: 379},
 		},
 		{
 			desc:       "with SAN",
@@ -63,7 +62,7 @@ func TestGenerateCSR(t *testing.T) {
 				SAN:        []string{"a.lego.acme", "b.lego.acme", "c.lego.acme"},
 				MustStaple: true,
 			},
-			expected: expected{len: 296},
+			expected: expected{len: 430},
 		},
 		{
 			desc:       "no domain",
@@ -72,7 +71,7 @@ func TestGenerateCSR(t *testing.T) {
 				Domain:     "",
 				MustStaple: true,
 			},
-			expected: expected{len: 225},
+			expected: expected{len: 359},
 		},
 		{
 			desc:       "no domain with SAN",
@@ -82,7 +81,7 @@ func TestGenerateCSR(t *testing.T) {
 				SAN:        []string{"a.lego.acme", "b.lego.acme", "c.lego.acme"},
 				MustStaple: true,
 			},
-			expected: expected{len: 276},
+			expected: expected{len: 409},
 		},
 		{
 			desc:       "private key nil",
@@ -101,7 +100,7 @@ func TestGenerateCSR(t *testing.T) {
 				SAN:            []string{"example.org"},
 				EmailAddresses: []string{"foo@example.com", "bar@example.com"},
 			},
-			expected: expected{len: 287},
+			expected: expected{len: 421},
 		},
 	}
 
@@ -124,17 +123,17 @@ func TestGenerateCSR(t *testing.T) {
 }
 
 func TestPEMEncode(t *testing.T) {
-	buf := bytes.NewBufferString("TestingRSAIsSoMuchFun")
-
-	reader := MockRandReader{b: buf}
-	key, err := rsa.GenerateKey(reader, 32)
+	key, err := rsa.GenerateKey(rand.Reader, 1024)
 	require.NoError(t, err, "Error generating private key")
 
 	data := PEMEncode(key)
 	require.NotNil(t, data)
 
-	exp := regexp.MustCompile(`^-----BEGIN RSA PRIVATE KEY-----\s+\S{60,}\s+-----END RSA PRIVATE KEY-----\s+`)
-	assert.Regexp(t, exp, string(data))
+	p, rest := pem.Decode(data)
+
+	assert.Equal(t, "RSA PRIVATE KEY", p.Type)
+	assert.Empty(t, rest)
+	assert.Empty(t, p.Headers)
 }
 
 func TestParsePEMCertificate(t *testing.T) {
@@ -169,10 +168,12 @@ func TestParsePEMPrivateKey(t *testing.T) {
 
 	pemPrivateKey := PEMEncode(privateKey)
 
-	// Decoding a key should work and create an identical key to the original
+	// Decoding a key should work and create an identical RSA key to the original,
+	// ignoring precomputed values.
 	decoded, err := ParsePEMPrivateKey(pemPrivateKey)
 	require.NoError(t, err)
-	assert.Equal(t, decoded, privateKey)
+	decodedRsaPrivateKey := decoded.(*rsa.PrivateKey)
+	require.True(t, decodedRsaPrivateKey.Equal(privateKey))
 
 	// Decoding a PEM block that doesn't contain a private key should error
 	_, err = ParsePEMPrivateKey(pem.EncodeToMemory(&pem.Block{Type: "CERTIFICATE"}))
@@ -186,11 +187,3 @@ func TestParsePEMPrivateKey(t *testing.T) {
 	_, err = ParsePEMPrivateKey([]byte("This is not PEM"))
 	require.Errorf(t, err, "Expected to return an error for non-PEM input")
 }
-
-type MockRandReader struct {
-	b *bytes.Buffer
-}
-
-func (r MockRandReader) Read(p []byte) (int, error) {
-	return r.b.Read(p)
-}
