@@ -24,8 +24,8 @@ func TestLookupNameserversOK(t *testing.T) {
 			nss:  []string{"ns1.google.com.", "ns2.google.com.", "ns3.google.com.", "ns4.google.com."},
 		},
 		{
-			fqdn: "physics.georgetown.edu.",
-			nss:  []string{"ns4.georgetown.edu.", "ns5.georgetown.edu.", "ns6.georgetown.edu."},
+			fqdn: "mail.proton.me.",
+			nss:  []string{"ns1.proton.me.", "ns2.proton.me.", "ns3.proton.me."},
 		},
 	}
 
@@ -39,7 +39,7 @@ func TestLookupNameserversOK(t *testing.T) {
 			sort.Strings(nss)
 			sort.Strings(test.nss)
 
-			assert.EqualValues(t, test.nss, nss)
+			assert.Equal(t, test.nss, nss)
 		})
 	}
 }
