@@ -107,7 +107,7 @@ func getOneWithFallback(main string, names ...string) (string, string) {
 
 // GetOrDefaultString returns the given environment variable value as a string.
 // Returns the default if the env var cannot be found.
-func GetOrDefaultString(envVar string, defaultValue string) string {
+func GetOrDefaultString(envVar, defaultValue string) string {
 	return getOrDefault(envVar, defaultValue, ParseString)
 }
 
@@ -184,3 +184,20 @@ func ParseString(s string) (string, error) {
 
 	return s, nil
 }
+
+// ParsePairs parses a raw string of comma-separated key-value pairs into a map.
+// Keys and values are separated by a colon and are trimmed of whitespace.
+func ParsePairs(raw string) (map[string]string, error) {
+	result := make(map[string]string)
+
+	for pair := range strings.SplitSeq(strings.TrimSuffix(raw, ","), ",") {
+		data := strings.Split(pair, ":")
+		if len(data) != 2 {
+			return nil, fmt.Errorf("incorrect pair: %s", pair)
+		}
+
+		result[strings.TrimSpace(data[0])] = strings.TrimSpace(data[1])
+	}
+
+	return result, nil
+}
