@@ -7,13 +7,12 @@ import (
 	"sync"
 	"time"
 
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/nrdcg/auroradns"
 )
 
-const defaultBaseURL = "https://api.auroradns.eu"
-
 // Environment variables names.
 const (
 	envNamespace = "AURORA_"
@@ -27,6 +26,10 @@ const (
 	EnvPollingInterval    = envNamespace + "POLLING_INTERVAL"
 )
 
+const defaultBaseURL = "https://api.auroradns.eu"
+
+var _ challenge.ProviderTimeout = (*DNSProvider)(nil)
+
 // Config is used to configure the creation of the DNSProvider.
 type Config struct {
 	BaseURL            string
