@@ -1,65 +1,79 @@
 package internal
 
 import (
-	"context"
 	"encoding/xml"
-	"fmt"
-	"io"
 	"net/http"
 	"net/http/httptest"
 	"testing"
 
+	"github.com/go-acme/lego/v4/platform/tester/servermock"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
+func mockBuilder(password string) *servermock.Builder[*Client] {
+	return servermock.NewBuilder[*Client](
+		func(server *httptest.Server) (*Client, error) {
+			client := NewClient("apiuser", password)
+			client.BaseURL = server.URL + "/"
+
+			return client, nil
+		},
+		servermock.CheckHeader().WithContentType("text/xml"),
+	)
+}
+
 func TestClient_AddZoneRecord(t *testing.T) {
-	serverResponses := map[string]string{
-		addZoneRecordGoodAuth:       responseOk,
-		addZoneRecordBadAuth:        responseAuthError,
-		addZoneRecordNonValidDomain: responseUnknownError,
-		addZoneRecordEmptyResponse:  "",
-	}
-
-	serverURL := createFakeServer(t, serverResponses)
-
 	testCases := []struct {
 		desc     string
 		password string
 		domain   string
+		request  string
+		response string
 		err      string
 	}{
 		{
 			desc:     "auth ok",
 			password: "goodpassword",
 			domain:   exampleDomain,
+			request:  addZoneRecordGoodAuth,
+			response: responseOk,
 		},
 		{
 			desc:     "auth error",
 			password: "badpassword",
 			domain:   exampleDomain,
+			request:  addZoneRecordBadAuth,
+			response: responseAuthError,
 			err:      "authentication error",
 		},
 		{
 			desc:     "unknown error",
 			password: "goodpassword",
 			domain:   "badexample.com",
+			request:  addZoneRecordNonValidDomain,
+			response: responseUnknownError,
 			err:      `unknown error: "UNKNOWN_ERROR"`,
 		},
 		{
 			desc:     "empty response",
 			password: "goodpassword",
 			domain:   "empty.com",
+			request:  addZoneRecordEmptyResponse,
+			response: "",
 			err:      "unmarshal error: EOF",
 		},
 	}
 
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
-			client := NewClient("apiuser", test.password)
-			client.BaseURL = serverURL + "/"
+			client := mockBuilder(test.password).
+				Route("POST /",
+					servermock.RawStringResponse(test.response),
+					servermock.CheckRequestBody(test.request)).
+				Build(t)
 
-			err := client.AddTXTRecord(context.Background(), test.domain, exampleSubDomain, 123, "TXTrecord")
+			err := client.AddTXTRecord(t.Context(), test.domain, exampleSubDomain, 123, "TXTrecord")
 			if test.err == "" {
 				require.NoError(t, err)
 			} else {
@@ -71,52 +85,56 @@ func TestClient_AddZoneRecord(t *testing.T) {
 }
 
 func TestClient_RemoveSubdomain(t *testing.T) {
-	serverResponses := map[string]string{
-		removeSubdomainGoodAuth:       responseOk,
-		removeSubdomainBadAuth:        responseAuthError,
-		removeSubdomainNonValidDomain: responseUnknownError,
-		removeSubdomainEmptyResponse:  "",
-	}
-
-	serverURL := createFakeServer(t, serverResponses)
-
 	testCases := []struct {
 		desc     string
 		password string
 		domain   string
+		request  string
+		response string
 		err      string
 	}{
 		{
 			desc:     "auth ok",
 			password: "goodpassword",
 			domain:   exampleDomain,
+			request:  removeSubdomainGoodAuth,
+			response: responseOk,
 		},
 		{
 			desc:     "auth error",
 			password: "badpassword",
 			domain:   exampleDomain,
+			request:  removeSubdomainBadAuth,
+			response: responseAuthError,
 			err:      "authentication error",
 		},
 		{
 			desc:     "unknown error",
 			password: "goodpassword",
 			domain:   "badexample.com",
+			request:  removeSubdomainNonValidDomain,
+			response: responseUnknownError,
 			err:      `unknown error: "UNKNOWN_ERROR"`,
 		},
 		{
 			desc:     "empty response",
 			password: "goodpassword",
 			domain:   "empty.com",
+			request:  removeSubdomainEmptyResponse,
+			response: "",
 			err:      "unmarshal error: EOF",
 		},
 	}
 
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
-			client := NewClient("apiuser", test.password)
-			client.BaseURL = serverURL + "/"
+			client := mockBuilder(test.password).
+				Route("POST /",
+					servermock.RawStringResponse(test.response),
+					servermock.CheckRequestBody(test.request)).
+				Build(t)
 
-			err := client.RemoveSubdomain(context.Background(), test.domain, exampleSubDomain)
+			err := client.RemoveSubdomain(t.Context(), test.domain, exampleSubDomain)
 			if test.err == "" {
 				require.NoError(t, err)
 			} else {
@@ -128,52 +146,56 @@ func TestClient_RemoveSubdomain(t *testing.T) {
 }
 
 func TestClient_RemoveZoneRecord(t *testing.T) {
-	serverResponses := map[string]string{
-		removeRecordGoodAuth:       responseOk,
-		removeRecordBadAuth:        responseAuthError,
-		removeRecordNonValidDomain: responseUnknownError,
-		removeRecordEmptyResponse:  "",
-	}
-
-	serverURL := createFakeServer(t, serverResponses)
-
 	testCases := []struct {
 		desc     string
 		password string
 		domain   string
+		request  string
+		response string
 		err      string
 	}{
 		{
 			desc:     "auth ok",
 			password: "goodpassword",
 			domain:   exampleDomain,
+			request:  removeRecordGoodAuth,
+			response: responseOk,
 		},
 		{
 			desc:     "auth error",
 			password: "badpassword",
 			domain:   exampleDomain,
+			request:  removeRecordBadAuth,
+			response: responseAuthError,
 			err:      "authentication error",
 		},
 		{
 			desc:     "uknown error",
 			password: "goodpassword",
 			domain:   "badexample.com",
+			request:  removeRecordNonValidDomain,
+			response: responseUnknownError,
 			err:      `unknown error: "UNKNOWN_ERROR"`,
 		},
 		{
 			desc:     "empty response",
 			password: "goodpassword",
 			domain:   "empty.com",
+			request:  removeRecordEmptyResponse,
+			response: "",
 			err:      "unmarshal error: EOF",
 		},
 	}
 
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
-			client := NewClient("apiuser", test.password)
-			client.BaseURL = serverURL + "/"
+			client := mockBuilder(test.password).
+				Route("POST /",
+					servermock.RawStringResponse(test.response),
+					servermock.CheckRequestBody(test.request)).
+				Build(t)
 
-			err := client.RemoveTXTRecord(context.Background(), test.domain, exampleSubDomain, 12345678)
+			err := client.RemoveTXTRecord(t.Context(), test.domain, exampleSubDomain, 12345678)
 			if test.err == "" {
 				require.NoError(t, err)
 			} else {
@@ -185,16 +207,13 @@ func TestClient_RemoveZoneRecord(t *testing.T) {
 }
 
 func TestClient_GetZoneRecord(t *testing.T) {
-	serverResponses := map[string]string{
-		getZoneRecords: getZoneRecordsResponse,
-	}
+	client := mockBuilder("goodpassword").
+		Route("POST /",
+			servermock.RawStringResponse(getZoneRecordsResponse),
+			servermock.CheckRequestBody(getZoneRecords)).
+		Build(t)
 
-	serverURL := createFakeServer(t, serverResponses)
-
-	client := NewClient("apiuser", "goodpassword")
-	client.BaseURL = serverURL + "/"
-
-	recordObjs, err := client.GetTXTRecords(context.Background(), exampleDomain, exampleSubDomain)
+	recordObjs, err := client.GetTXTRecords(t.Context(), exampleDomain, exampleSubDomain)
 	require.NoError(t, err)
 
 	expected := []RecordObj{
@@ -210,23 +229,11 @@ func TestClient_GetZoneRecord(t *testing.T) {
 }
 
 func TestClient_rpcCall_404(t *testing.T) {
-	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		_, err := io.ReadAll(r.Body)
-		if err != nil {
-			http.Error(w, err.Error(), http.StatusBadRequest)
-			return
-		}
-
-		w.WriteHeader(http.StatusNotFound)
-
-		_, err = fmt.Fprint(w, "<?xml version='1.0' encoding='UTF-8'?>")
-		if err != nil {
-			http.Error(w, err.Error(), http.StatusInternalServerError)
-			return
-		}
-	}))
-
-	t.Cleanup(server.Close)
+	client := mockBuilder("apipassword").
+		Route("POST /",
+			servermock.RawStringResponse("<?xml version='1.0' encoding='UTF-8'?>").
+				WithStatusCode(http.StatusNotFound)).
+		Build(t)
 
 	call := &methodCall{
 		MethodName: "dummyMethod",
@@ -235,29 +242,15 @@ func TestClient_rpcCall_404(t *testing.T) {
 		},
 	}
 
-	client := NewClient("apiuser", "apipassword")
-	client.BaseURL = server.URL + "/"
-
-	err := client.rpcCall(context.Background(), call, &responseString{})
+	err := client.rpcCall(t.Context(), call, &responseString{})
 	require.EqualError(t, err, "unexpected status code: [status code: 404] body: <?xml version='1.0' encoding='UTF-8'?>")
 }
 
 func TestClient_rpcCall_RPCError(t *testing.T) {
-	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		_, err := io.ReadAll(r.Body)
-		if err != nil {
-			http.Error(w, err.Error(), http.StatusBadRequest)
-			return
-		}
-
-		_, err = fmt.Fprint(w, responseRPCError)
-		if err != nil {
-			http.Error(w, err.Error(), http.StatusInternalServerError)
-			return
-		}
-	}))
-
-	t.Cleanup(server.Close)
+	client := mockBuilder("apipassword").
+		Route("POST /",
+			servermock.RawStringResponse(responseRPCError)).
+		Build(t)
 
 	call := &methodCall{
 		MethodName: "getDomains",
@@ -266,10 +259,7 @@ func TestClient_rpcCall_RPCError(t *testing.T) {
 		},
 	}
 
-	client := NewClient("apiuser", "apipassword")
-	client.BaseURL = server.URL + "/"
-
-	err := client.rpcCall(context.Background(), call, &responseString{})
+	err := client.rpcCall(t.Context(), call, &responseString{})
 	require.EqualError(t, err, "RPC Error: (201) Method signature error: 42")
 }
 
@@ -301,37 +291,3 @@ func TestUnmarshallFaultyRecordObject(t *testing.T) {
 		})
 	}
 }
-
-func createFakeServer(t *testing.T, serverResponses map[string]string) string {
-	t.Helper()
-
-	handler := http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		if r.Header.Get("Content-Type") != "text/xml" {
-			http.Error(w, fmt.Sprintf("invalid content type: %s", r.Header.Get("Content-Type")), http.StatusBadRequest)
-			return
-		}
-
-		req, err := io.ReadAll(r.Body)
-		if err != nil {
-			http.Error(w, err.Error(), http.StatusBadRequest)
-			return
-		}
-
-		resp, ok := serverResponses[string(req)]
-		if !ok {
-			http.Error(w, "no response for request", http.StatusBadRequest)
-			return
-		}
-
-		_, err = fmt.Fprint(w, resp)
-		if err != nil {
-			http.Error(w, err.Error(), http.StatusInternalServerError)
-			return
-		}
-	})
-
-	server := httptest.NewServer(handler)
-	t.Cleanup(server.Close)
-
-	return server.URL
-}
