@@ -9,6 +9,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/go-acme/lego/v4/providers/dns/internal/useragent"
@@ -16,15 +17,6 @@ import (
 	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
-const (
-	minTTL                    = 60
-	defaultPollingInterval    = 10 * time.Second
-	defaultPropagationTimeout = 120 * time.Second
-)
-
-// The access key is not used by the Scaleway client.
-const dumpAccessKey = "SCWXXXXXXXXXXXXXXXXX"
-
 // Environment variables names.
 const (
 	envNamespace = "SCALEWAY_"
@@ -42,6 +34,17 @@ const (
 	EnvPollingInterval    = envNamespace + "POLLING_INTERVAL"
 )
 
+const (
+	minTTL                    = 60
+	defaultPollingInterval    = 10 * time.Second
+	defaultPropagationTimeout = 120 * time.Second
+)
+
+// The access key is not used by the Scaleway client.
+const dumpAccessKey = "SCWXXXXXXXXXXXXXXXXX"
+
+var _ challenge.ProviderTimeout = (*DNSProvider)(nil)
+
 // Config is used to configure the creation of the DNSProvider.
 type Config struct {
 	ProjectID          string
